package com.ruoyi.bst.prodProcess.service.impl;

import com.ruoyi.bst.prodProcess.domain.ProdProcess;
import com.ruoyi.bst.prodProcess.domain.ProdProcessQuery;
import com.ruoyi.bst.prodProcess.domain.ProdProcessVO;
import com.ruoyi.bst.prodProcess.mapper.ProdProcessMapper;
import com.ruoyi.bst.prodProcess.service.IProdProcessService;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 产品工序Service业务层处理
 *
 * @author ruoyi
 * @date 2024-12-17
 */
@Service
public class ProdProcessServiceImpl implements IProdProcessService
{
    @Autowired
    private ProdProcessMapper prodProcessMapper;

    /**
     * 查询产品工序
     *
     * @param id 产品工序主键
     * @return 产品工序
     */
    @Override
    public ProdProcessVO selectProdProcessById(Long id)
    {
        return prodProcessMapper.selectProdProcessById(id);
    }

    /**
     * 查询产品工序列表
     *
     * @param prodProcess 产品工序
     * @return 产品工序
     */
    @Override
    public List<ProdProcessVO> selectProdProcessList(ProdProcessQuery prodProcess)
    {
        return prodProcessMapper.selectProdProcessList(prodProcess);
    }

    /**
     * 新增产品工序
     *
     * @param prodProcess 产品工序
     * @return 结果
     */
    @Override
    public int insertProdProcess(ProdProcess prodProcess)
    {
        prodProcess.setCreateTime(DateUtils.getNowDate());
        return prodProcessMapper.insertProdProcess(prodProcess);
    }

    /**
     * 修改产品工序
     *
     * @param prodProcess 产品工序
     * @return 结果
     */
    @Override
    public int updateProdProcess(ProdProcess prodProcess)
    {
        return prodProcessMapper.updateProdProcess(prodProcess);
    }

    /**
     * 批量删除产品工序
     *
     * @param ids 需要删除的产品工序主键
     * @return 结果
     */
    @Override
    public int deleteProdProcessByIds(Long[] ids)
    {
        return prodProcessMapper.deleteProdProcessByIds(ids);
    }

    /**
     * 删除产品工序信息
     *
     * @param id 产品工序主键
     * @return 结果
     */
    @Override
    public int deleteProdProcessById(Long id)
    {
        return prodProcessMapper.deleteProdProcessById(id);
    }
}
